@@ -1,16 +1,17 @@
 import os
-import re
 import signal
 import socket
 
 from daemon import DaemonContext
 from datetime import datetime
 from lock import Lock
-from os.path import getmtime
-from subprocess import PIPE, STDOUT, Popen
+from os import mkdir
+from os.path import getmtime, exists
 
 from netifaces import interfaces, ifaddresses
 
+from ojota import set_data_source
+
 
 LOCKFILE = "/tmp/touchandgo"
 
@@ -30,7 +31,8 @@ def get_interface():
             for item in address:
                 if item.get('netmask') is not None and \
                         not item['addr'].startswith("127") and \
-                        not item['addr'].startswith(":"):
+                        not item['addr'].startswith(":") and \
+                        len(item['addr']) < 17:
                     return item['addr']
 
 
@@ -42,24 +44,6 @@ def is_process_running(process_id):
         return False
 
 
-def execute(command):
-    process = Popen(command, shell=True, stdout=PIPE, stderr=STDOUT)
-    print("Running peerflix")
-    while True:
-        nextline = process.stdout.readline()
-        urls = re.findall('http[s]?://(?:[a-zA-Z]|[0-9]|[$-_@.&+]|[!*\(\),]|(?:%[0-9a-fA-F][0-9a-fA-F]))+',
-                          nextline)
-        if len(urls):
-            print("streaming url: %s" % urls[0])
-            break
-        if nextline == '' and process.poll() is not None:
-            break
-
-    output = process.communicate()[0]
-    exitCode = process.returncode
-    #print output, exitCode
-
-
 def daemonize(args, callback):
     with DaemonContext():
         create_process = False
@@ -97,3 +81,12 @@ def get_lock_diff():
     except OSError:
         pass
     return timediff
+
+
+def set_config_dir():
+    data_folder = "%s/.touchandgo" % os.getenv("HOME")
+    if not exists(data_folder):
+        mkdir(data_folder)
+
+    set_data_source(data_folder)
+
